%define _default_patch_fuzz 2

%define version 24.0
%define release %mkrel 1

Summary: The boot loader for Linux and other operating systems
Name: lilo
Version: %{version}
Release: %{release}
Epoch: 1
License: MIT
Group: System/Boot and Init
URL: http://lilo.alioth.debian.org/
Source: http://lilo.alioth.debian.org/ftp/sources/%{name}-%{version}.tar.gz
#Source: ftp://lrcftp.epfl.ch/pub/linux/local/lilo/
Source1: mageia_256c.uu
Source2: mageia_256c.dat
Patch0: lilo-21.6-keytab-3mdk.patch
Patch1: lilo-disks-without-partitions.patch
Patch9: lilo-22.5.1-unsafe-and-default-table.patch
Patch26: lilo-22.5.9-longer_image_names.patch
# [Pixel] the following patch was introduced in 2004 by Juan Quintela,
# it may be needed by longer_image_names patch above, but it seems unneeded
Patch27: lilo-two_columns.patch
Patch28: lilo-22.5.9-never-relocate-when-has-partititions.patch
Patch29: lilo-22.5.9-initialize-Volume-IDs-with-no-fanfare.patch
Patch31: lilo-exit_code_1_when_aborting.patch
Patch32: lilo-22.6.1-turn-non-valid-boot-signature-into-a-warning.patch
Patch35: lilo-22.6.1-large-memory-option-by-default.patch
Patch36: lilo-23.2-no-debian.patch
Patch37: lilo-24.0-Fix-make-install-when-lilo.static-is-not-built.patch
BuildRequires: texlive dev86 dev86-devel nasm
BuildRequires: device-mapper-devel
BuildRequires: sharutils
Requires(post): perl-base
Provides: bootloader
Conflicts: lilo-doc < 22.5.7.2-6
ExclusiveArch: %{ix86} x86_64

%package doc
Summary: More doc for %{name}
Group: Documentation
Conflicts: lilo < 22.5.7.2-6

%description
LILO (LInux LOader) is a basic system program which boots your Linux
system.  LILO loads the Linux kernel from a floppy or a hard drive, boots
the kernel and passes control of the system to the kernel.  LILO can also
boot other operating systems.

%description doc
cf %{name} package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch9 -p1
%patch26 -p1 -b .images
%patch27 -p1 -b .two
%patch28 -p1
%patch29 -p1
%patch31 -p1 -b .exit_code
%patch32 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1

bzip2 -9 README*

cp -a %{SOURCE1} %{SOURCE2} images/

# disable diagnostic build (which would need beeing root)
perl -pi -e 's/^(diagnostic:).*/diagnostic:/' Makefile

%build
perl -p -i -e "s/-Wall -g/$RPM_OPT_FLAGS/" Makefile
make all
(cd doc
make -f Makefile.old CFLAGS="$RPM_OPT_FLAGS -DDEBUG"
dvipdfm -o User_Guide.pdf user.dvi
dvipdfm -o Technical_Guide.pdf tech.dvi
rm -f *.aux *.log *.toc)

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

install -d $RPM_BUILD_ROOT%{_bindir}
mv $RPM_BUILD_ROOT/usr/sbin/* $RPM_BUILD_ROOT%{_bindir}

rm -rf $RPM_BUILD_ROOT/etc/initramfs $RPM_BUILD_ROOT/etc/kernel $RPM_BUILD_ROOT/etc/lilo.conf_example

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -f /etc/lilo.conf ]; then

  if [ -L /boot/lilo ]; then

      # upgrading from old lilo boot.b based

      # before:
      # - message is a symlink to either lilo-text/message, lilo-menu/message or lilo-graphic/message
      # - lilo-text/message and lilo-menu/message are created by DrakX (and are usually the same file)
      # - lilo-graphic/message is in the RPM (will be removed by RPM after %post)
      # after:
      # - message-text is the text message
      # - message-graphic is the old lilo-graphic/message

      # transforming the /boot/message symlink in non-symlink
      if [ -e /boot/lilo-text/message ]; then
	  mv -f /boot/lilo-text/message /boot/message-text
      fi
      if [ -e /boot/lilo-menu/message ]; then
	  mv -f /boot/lilo-menu/message /boot/message-text
      fi

      if [ -e /boot/message-text ]; then
          ln -sf message-text /boot/message
      fi

      # ensuring the right choice is taken

      link=`perl -e 'print readlink("/boot/lilo")'`
      case $link in
        lilo-menu) ;; # chosen by default
        lilo-bmp) ;; # automatically chosen by lilo based on "bitmap=..."
        lilo-graphic) ;; # obsolete
        lilo-text)
          # need a special install=...
  	  perl -pi -e 's|^install=.*\n||; $_ = "install=text\n$_" if $. == 1' /etc/lilo.conf ;;
        *)
	  echo "ERROR: unknown lilo scheme, it is DROPPED (please file a bug at http://bugs.mageia.org)"
	  sleep 1 ;;
      esac

      rm -f /boot/lilo
  elif [ -e /boot/message-graphic ]; then
      if perl -e 'exit(-s "/boot/message" > 65_000 ? 0 : 1)'; then
      	 link=`perl -e 'print readlink("/boot/message")'`
	 rm /boot/message
	 if [ "$link" = "message-graphic" -a -e /boot/message-text ]; then
	   ln -s message-text /boot/message
	   if perl -e 'exit(-s "/boot/message" > 65_000 ? 0 : 1)'; then
 	     # weird message-text file... well someone had this on cooker, better be safe
	     echo > /boot/message
           fi
         else
	   echo > /boot/message
         fi
      fi
  fi

  chmod 600 /etc/lilo.conf
  if [ -x /usr/sbin/detectloader ]; then
    LOADER=$(/usr/sbin/detectloader -q)
    if [ "$LOADER" = "LILO" ]; then
      /sbin/lilo > /dev/null
    fi
  fi
fi

%files
%defattr(-,root,root)
%doc README* COPYING
/sbin/*
%{_bindir}/*
%{_mandir}/*/*
/boot/mageia.bmp

%files doc
%defattr(-,root,root)
%doc doc/*.pdf QuickInst



%changelog
* Fri Oct 18 2013 pterjan <pterjan> 1:24.0-1.mga4
+ Revision: 522057
- 24.0 (Fix build with recent GCC + Add GPT support)
- Fix make install when not building lilo.static

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Mon Jan 21 2013 barjac <barjac> 1:23.2-4.mga3
+ Revision: 390316
- update group

* Sat Jan 12 2013 umeabot <umeabot> 1:23.2-3.mga3
+ Revision: 358789
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun May 15 2011 pterjan <pterjan> 1:23.2-2.mga1
+ Revision: 98943
- Rebuild for fixed find-requires

* Sun Apr 17 2011 pterjan <pterjan> 1:23.2-1.mga1
+ Revision: 87249
- Update to 23.2
- Replace Debian images with a Mageia one, even if drakx no longer supports setting graphic menu in lilo

* Wed Mar 30 2011 ahmad <ahmad> 1:22.8-6.mga1
+ Revision: 78988
- replace tetex BR with texlive

* Mon Jan 10 2011 tmb <tmb> 1:22.8-5.mga1
+ Revision: 4946
- imported package lilo


* Mon Jan 10 2011 Thomas Backlund <tmb@mageia.org> 1:22.8-5.mga1
- initial Mageia import
- drop rpm tags
- redirect bug reports to bugs.mageia.org

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1:22.8-4mdv2011.0
+ Revision: 606409
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1:22.8-3mdv2010.1
+ Revision: 523188
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:22.8-2mdv2010.0
+ Revision: 425978
- rebuild

* Wed Jan 07 2009 Pixel <pixel@mandriva.com> 1:22.8-1mdv2009.1
+ Revision: 326625
- 22.8
- always build with device-mapper (support for it is now upstream)
- rediff patch27 (two_columns), but is this really needed?
- rediff patches: patch31 (exit_code)
- adapt patch22 (mandir)
- drop patch30: test-edd.b was not compiled by default anyway
- drop patches applied upstream: patch34 (UUID), patch98 (dm)

* Fri Aug 22 2008 Pixel <pixel@mandriva.com> 1:22.6.1-15mdv2009.0
+ Revision: 275134
- use "large-memory" by default to workaround BIOS issues with big initrd (esp. since splashy)

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 1:22.6.1-14mdv2009.0
+ Revision: 223107
- rebuild

* Tue Jan 22 2008 Pixel <pixel@mandriva.com> 1:22.6.1-13mdv2008.1
+ Revision: 156251
- handle root="UUID=xxx"

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1:22.6.1-12mdv2008.1
+ Revision: 136572
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - s/Mandrake/Mandriva/

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 1:22.6.1-12mdv2008.0
+ Revision: 69356
- kill file require on perl-base

* Sun Jul 01 2007 Christiaan Welvaart <spturtle@mandriva.org> 1:22.6.1-11mdv2008.0
+ Revision: 46288
- enable x86-64 native package


* Mon Feb 26 2007 Pixel <pixel@mandriva.com> 22.6.1-10mdv2007.0
+ Revision: 125911
- cdrecord is wodim, mkisofs is genisoimage (#28899)

* Wed Dec 06 2006 Pixel <pixel@mandriva.com> 1:22.6.1-9mdv2007.1
+ Revision: 91816
- handle message-text not really being text
- check message file smaller than 65K (which is what lilo checks)

* Tue Dec 05 2006 Pixel <pixel@mandriva.com> 1:22.6.1-8mdv2007.1
+ Revision: 91136
- drop lilo-graphic support
  (rationale: favoring of grub+gfxboot, vs the cryptic bmp2mdk)
- use %%mkrel
- Import lilo

* Wed May 24 2006 Pixel <pixel@mandriva.com> 22.6.1-7mdk
- rebuild with libdevmapper 1.02
- replace PreReq with Requires(post)

* Tue Sep 13 2005 Pixel <pixel@mandriva.com> 22.6.1-6mdk
- put 2006 splash screen

* Tue Apr 05 2005 Pixel <pixel@mandrakesoft.com> 22.6.1-5mdk
- put 10.2 final splash screen

* Mon Mar 28 2005 Luca Berra <bluca@vodka.it> 22.6.1-4mdk 
- fix error when /dev/dm-? exist

* Sat Mar 05 2005 Luca Berra <bluca@vodka.it> 22.6.1-3mdk 
- rebuild for new libdevmapper

* Sat Jan 15 2005 Pixel <pixel@mandrakesoft.com> 22.6.1-2mdk
- make "First sector of %%s doesn't have a valid boot signature"
  a warning instead of an error (bugzilla #5337)

* Tue Nov 23 2004 Pixel <pixel@mandrakesoft.com> 22.6.1-1mdk
- new release
- don't build diagnostic images

* Fri Nov 12 2004 Pixel <pixel@mandrakesoft.com> 22.6-1mdk
- new release

* Tue Sep 28 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-10mdk
- put 10.1 final splash screen

* Wed Sep 22 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-9mdk
- add README.test_bios in patch test-edd

* Tue Sep 21 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-8mdk
- fix the xxx.bmp.parameters

* Wed Sep 15 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-7mdk
- put 10.1 splash screen (and use the xxx.bmp.parameters)

* Fri Sep 10 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-6mdk
- exit_code_1 when aborting
- add patch to build test-edd.b 
  (build, then define TEST_EDD in first.S, build again, then use first.b)

* Wed Aug 18 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-5mdk
- add patch initialize-Volume-IDs-with-no-fanfare
  (to initialize Volume IDs without prompting)

* Sat Aug 07 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-4mdk
- never-relocate-when-has-partititions (lilo tries to skip overwriting
  the first 0x40 bytes of the devices when it detects a dos bootsector,
  alas it can detect one on the MBR)

* Tue Aug 03 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-3mdk
- lilo-bmp2mdk: accept bmp images with palette bigger than 
  128 colors *if* colors above 128 are not used

* Sat Jul 31 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-2mdk
- merge in graphic patch21 allgraph (patch23) and progress (patch24)
- add handling of xxx.bmp.parameters in lilo-bmp2mdk
  to generate xxx.bmp.parameters use drakxplash2 (until merged in draksplash)

* Tue Jul 06 2004 Pixel <pixel@mandrakesoft.com> 22.5.9-1mdk
- new release
